Crate rustfs_mimalloc_sys

Crate rustfs_mimalloc_sys 

Low-level FFI bindings to mimalloc V3 (v3.5.2).

For a safe wrapper, use the rustfs-mimalloc crate.

Structs

mi_heap_area_t
mi_heap_t
mi_profiler_sample_data_t
mi_profiler_t
Experimental mimalloc profiling hook table.
mi_subproc_id_t
Subprocess identifier. Opaque handle — do not access fields directly.
mi_theap_t

Enums

c_void
Equivalent to C’s void type when used as a pointer.
mi_option_t

Constants

MI_PROFILE_SAMPLE_DATA_MAX_SIZE
Maximum user data bytes stored inline with a sampled profiling allocation.
MI_SMALL_SIZE_MAX
Maximum byte size for mimalloc’s small allocation fast path.
MI_SMALL_WSIZE_MAX
Maximum word count for mimalloc’s small allocation fast path.

Functions

mi_arena_max_object_size
mi_arena_min_alignment
mi_arena_min_size
mi_calloc
mi_calloc_aligned
mi_collect
mi_free
mi_free_csize
Free an allocation when the size is statically known by the caller.
mi_free_csize_nonnull
Free a non-null allocation when the size is statically known by the caller.
mi_free_size
mi_free_small
mi_free_small_nonnull
mi_good_size
mi_heap_calloc
mi_heap_collect
mi_heap_contains
mi_heap_delete
mi_heap_destroy
mi_heap_main
mi_heap_malloc
mi_heap_malloc_aligned
mi_heap_new
mi_heap_new_in_arena
mi_heap_of
mi_heap_profile
mi_heap_profile_disable
mi_heap_realloc
mi_heap_stats_get_json
mi_heap_stats_print_out
mi_heap_theap
mi_heap_zalloc
mi_malloc
mi_malloc_aligned
mi_malloc_csize
Allocate when the size is statically known by the caller.
mi_malloc_size
mi_malloc_small
mi_malloc_usable_size
mi_mallocn
mi_manage_os_memory_ex
mi_memalign
mi_option_disable
mi_option_enable
mi_option_get
mi_option_get_size
mi_option_is_enabled
mi_option_set
mi_posix_memalign
mi_process_info
mi_process_info_print_out
mi_profile
mi_profiler_start
mi_profiler_stop
mi_realloc
mi_realloc_aligned
mi_reallocn
mi_reserve_os_memory_ex
mi_stats_get_json
mi_stats_print_out
mi_stats_reset
mi_strdup
mi_subproc_profile
mi_theap_malloc
mi_theap_malloc_csize
Allocate from a thread-local heap when the size is statically known.
mi_theap_malloc_small
mi_theap_stats_merge_to_heap
mi_theap_wmalloc_small
mi_theap_wzalloc_small
mi_theap_zalloc
mi_theap_zalloc_csize
Allocate zeroed memory from a thread-local heap when the size is statically known.
mi_theap_zalloc_small
mi_thread_set_in_threadpool
mi_usable_size
mi_version
mi_wmalloc_small
mi_wsize_from_size
Convert a byte size to a mimalloc machine-word count.
mi_wzalloc_small
mi_zalloc
mi_zalloc_aligned
mi_zalloc_csize
Allocate zeroed memory when the size is statically known by the caller.
mi_zalloc_small

Type Aliases

c_char
Equivalent to C’s char type.
c_int
Equivalent to C’s signed int (int) type.
c_long
Equivalent to C’s signed long (long) type.
mi_arena_id_t
Arena identifier. Opaque handle.
mi_block_visit_fun
mi_deferred_free_fun
mi_error_fun
mi_heap_visit_fun
mi_output_fun
mi_profiler_on_alloc_fun
mi_profiler_on_free_fun
mi_profiler_on_realloc_inplace_fun
size_t