mi_free_csize_nonnull

Function mi_free_csize_nonnull 

pub unsafe fn mi_free_csize_nonnull(p: *mut c_void, size: size_t)
Free a non-null allocation when the size is statically known by the caller.

This mirrors mimalloc’s inline mi_free_csize_nonnull helper.

Safety

p must be a non-null valid mimalloc allocation, and size must be the allocation size used for the corresponding allocation.