mi_free_csize

Function mi_free_csize 

pub unsafe fn mi_free_csize(p: *mut c_void, size: size_t)
Free an allocation when the size is statically known by the caller.

This mirrors mimalloc’s inline mi_free_csize helper.

Safety

p must be null or a valid mimalloc allocation, and size must be the allocation size used for the corresponding allocation.